/* Copyright (C) 2023 Physikalisches Institut, Eberhard Karls Universitaet Tuebingen, Tuebingen
   SPDX-License-Identifier: GPL-3.0-only
   Authors: Volker Friese, Florian Uhlig, Lukas Chlad [committer] */

/** CbmFsdHit.cxx
 **@author Lukas Chlad <l.chlad@gsi.de>
 **@since 15.06.2023
 **
 **/
#include "CbmFsdHit.h"

#include "CbmHit.h"  // for kFSDHIT

#include <Logger.h>  // for Logger, LOG

// -----   Default constructor   -------------------------------------------
CbmFsdHit::CbmFsdHit() : CbmPixelHit(), fModuleID(-1), fEdep(-1)
{
  SetType(kFSDHIT);
  SetTime(0.);
}
CbmFsdHit::CbmFsdHit(int32_t module, double edep) : CbmPixelHit(), fModuleID(module), fEdep(edep)
{
  SetType(kFSDHIT);
  SetTime(0.);
}


// -----   Destructor   ----------------------------------------------------
CbmFsdHit::~CbmFsdHit() {}
// -------------------------------------------------------------------------

void CbmFsdHit::Print(Option_t*) const { LOG(info) << ToString(); }

std::string CbmFsdHit::ToString() const
{
  std::stringstream ss;
  ss << "module : " << fModuleID << "position: [" << GetX() << "," << GetY() << "," << GetZ() << "] "
     << " ELoss " << fEdep;
  return ss.str();
}

ClassImp(CbmFsdHit)
